# PytCube: Efficient multidimensional subsetting around observation points

*PytCube* is a Python library for extracting small **subsets (mini-cubes)** around observation points within large **multidimensional datasets**.

It works with **any N-dimensional grid**, allowing flexible colocation of points in space, time, or any other dimensions.

**Useful links:** [Code Repository](https://gitlab.ifremer.fr/odatis-public/pytcube) | [Issues](https://gitlab.ifremer.fr/odatis-public/pytcube/issues)

```{toctree}
  :maxdepth: 1
  :hidden:

getting-started/index
examples/index
Development <development>
```

<!--
## Getting Started

New to *PytCube*? Check out the getting started guides. They contain an
introduction to *PytCube's* main concepts.

```{toctree}
:maxdepth: 2

getting-started/index
```

## User Guide

The user guide provides in-depth information on the key concepts of PytCube with useful background information and explanation.

```{toctree}
:maxdepth: 2

user-guide/index
```

## API Reference

The reference guide contains a detailed description of the PytCube API.
The reference describes how the methods work and which parameters can
be used. It assumes that you have an understanding of the key concepts.

```{toctree}
:maxdepth: 2

api/index
```

## Examples

Here are examples of PytCube use cases within various scientific applications.

```{toctree}
:maxdepth: 2

examples/index
``` -->
